<?php
/**
 * Bwater functions and definitions
 *
 * Sets up the theme and provides some helper functions. Some helper functions
 * are used in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * When using a child theme (see http://codex.wordpress.org/Theme_Development and
 * http://codex.wordpress.org/Child_Themes), you can override certain functions
 * (those wrapped in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before the parent
 * theme's file, so the child theme functions would be used.
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are instead attached
 * to a filter or action hook. The hook can be removed by using remove_action() or
 * remove_filter() and you can attach your own function to the hook.
 *
 * For more information on hooks, actions, and filters, see http://codex.wordpress.org/Plugin_API.
 *
 * @package Bwater
 * @since Bwater 1.0
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
   $content_width = 640; /* pixels */

if ( ! function_exists( 'bwater_setup' ) ):
   /**
    * Sets up theme defaults and registers support for various WordPress features.
    *
    * Note that this function is hooked into the after_setup_theme hook, which runs
    * before the init hook. The init hook is too late for some features, such as indicating
    * support post thumbnails.
    *
    * To override bwater_setup() in a child theme, add your own bwater_setup to your child theme's
    * functions.php file.
    */
   function bwater_setup() {
      /**
       * Make theme available for translation
       * Translations can be filed in the /languages/ directory
       * If you're building a theme based on bwater, use a find and replace
       * to change 'bwater' to the name of your theme in all the template files
       */
      load_theme_textdomain( 'bwater', get_template_directory() . '/languages' );

      $locale = get_locale();
      $locale_file = get_template_directory() . "/languages/$locale.php";
      if ( is_readable( $locale_file ) )
         require_once( $locale_file );

      /**
       * Add default posts and comments RSS feed links to head
       */
      add_theme_support( 'automatic-feed-links' );

      /**
       * This theme uses wp_nav_menu() in one location.
       */
      register_nav_menus( array(
         'primary' => __( 'Primary Menu', 'bwater' ),
      ) );

      /**
       * Add support for the Aside and Gallery Post Formats
       */
      add_theme_support( 'post-formats', array( 'aside', 'image', 'gallery' ) );
   }
endif; // bwater_setup

/**
 * Tell WordPress to run bwater_setup() when the 'after_setup_theme' hook is run.
 */
add_action( 'after_setup_theme', 'bwater_setup' );

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */
function bwater_page_menu_args( $args ) {
   $args['show_home'] = true;
   return $args;
}
add_filter( 'wp_page_menu_args', 'bwater_page_menu_args' );

/**
 * Register widgetized area and update sidebar with default widgets
 */
function bwater_widgets_init() {
   register_sidebar( array(
      'name' => __( 'Sidebar 1', 'bwater' ),
      'id' => 'sidebar-1',
      'before_widget' => '<aside id="%1$s" class="widget %2$s">',
      'after_widget' => "</aside>",
      'before_title' => '<h1 class="widget-title">',
      'after_title' => '</h1>',
   ) );
}

add_action( 'init', 'bwater_widgets_init' );

if ( ! function_exists( 'bwater_content_nav' ) ):
   /**
    * Display navigation to next/previous pages when applicable
    *
    * @since Bwater 1.0
    */
   function bwater_content_nav( $nav_id ) {
      global $wp_query;

?>
<nav id="<?php echo $nav_id; ?>">

   <?php if ( is_single() ) : // navigation links for single posts ?>

   <?php previous_post_link( '<div class="nav-previous">%link</div>', '%title' ); ?>
   <?php next_post_link( '<div class="nav-next">%link</div>', '%title' ); ?>

   <?php elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : // navigation links for home, archive, and search pages ?>

   <?php if ( get_next_posts_link() ) : ?>
   <div class="nav-previous"><?php next_posts_link( __( 'Older posts', 'bwater' ) ); ?></div>
   <?php endif; ?>

   <?php if ( get_previous_posts_link() ) : ?>
   <div class="nav-next"><?php previous_posts_link( __( 'Newer posts', 'bwater' ) ); ?></div>
   <?php endif; ?>

   <?php endif; ?>

</nav><!-- #<?php echo $nav_id; ?> -->
<?php
   }
endif; // bwater_content_nav


if ( ! function_exists( 'bwater_comment' ) ) :
   /**
    * Template for comments and pingbacks.
    *
    * To override this walker in a child theme without modifying the comments template
    * simply create your own bwater_comment(), and that function will be used instead.
    *
    * Used as a callback by wp_list_comments() for displaying the comments.
    *
    * @since Bwater 0.4
    */
   function bwater_comment( $comment, $args, $depth ) {
      $GLOBALS['comment'] = $comment;
      switch ( $comment->comment_type ) :
      case 'pingback' :
      case 'trackback' :
?>
<li class="post pingback">
   <p><?php _e( 'Pingback:', 'bwater' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( '(Edit)', 'bwater' ), ' ' ); ?></p>
<?php
         break;
      default :
?>
   <li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
      <article id="comment-<?php comment_ID(); ?>" class="comment">
         <footer>
            <div class="comment-author vcard">
               <?php echo get_avatar( $comment, 40 ); ?>
               <?php printf( __( '%s <span class="says">says:</span>', 'bwater' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
            </div><!-- .comment-author .vcard -->
            <?php if ( $comment->comment_approved == '0' ) : ?>
            <em><?php _e( 'Your comment is awaiting moderation.', 'bwater' ); ?></em>
            <br />
            <?php endif; ?>

            <div class="comment-meta commentmetadata">
               <a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>"><time datetime="<?php comment_time( 'c' ); ?>">
<?php
         /* translators: 1: date, 2: time */
         printf( __( '%1$s at %2$s', 'bwater' ), get_comment_date(), get_comment_time() ); ?>
               </time></a>
<?php edit_comment_link( __( '(Edit)', 'bwater' ), ' ' );
?>
            </div><!-- .comment-meta .commentmetadata -->
         </footer>

         <div class="comment-content"><?php comment_text(); ?></div>

         <div class="reply">
            <?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
         </div><!-- .reply -->
      </article><!-- #comment-## -->

<?php
break;
endswitch;
   }
endif; // ends check for bwater_comment()

if ( ! function_exists( 'bwater_posted_on' ) ) :
   /**
    * Prints HTML with meta information for the current post-date/time and author.
    * Create your own bwater_posted_on to override in a child theme
    *
    * @since Bwater 1.2
    */
   function bwater_posted_on() {
      printf( __( '<span class="posted-on">Posted on </span><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a><span class="byline"> <span class="by"> by </span> <span class="author vcard"><a class="url fn n" href="%5$s" title="%6$s" rel="author">%7$s</a></span></span>', 'bwater' ),
         esc_url( get_permalink() ),
         esc_attr( get_the_time() ),
         esc_attr( get_the_date( 'c' ) ),
         esc_html( get_the_date() ),
         esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
         esc_attr( sprintf( __( 'View all posts by %s', 'bwater' ), get_the_author() ) ),
         esc_html( get_the_author() )
      );
   }
endif;

/**
 * Adds custom classes to the array of body classes.
 *
 * @since Bwater 1.2
 */
function bwater_body_classes( $classes ) {
   // Adds a class of single-author to blogs with only 1 published author
   if ( ! is_multi_author() ) {
      $classes[] = 'single-author';
   }

   return $classes;
}
add_filter( 'body_class', 'bwater_body_classes' );

/**
 * Returns true if a blog has more than 1 category
 *
 * @since Bwater 1.2
 */
function bwater_categorized_blog() {
   if ( false === ( $all_the_cool_cats = get_transient( 'all_the_cool_cats' ) ) ) {
      // Create an array of all the categories that are attached to posts
      $all_the_cool_cats = get_categories( array(
         'hide_empty' => 1,
      ) );

      // Count the number of categories that are attached to the posts
      $all_the_cool_cats = count( $all_the_cool_cats );

      set_transient( 'all_the_cool_cats', $all_the_cool_cats );
   }

   if ( '1' != $all_the_cool_cats ) {
      // This blog has more than 1 category so bwater_categorized_blog should return true
      return true;
   } else {
      // This blog has only 1 category so bwater_categorized_blog should return false
      return false;
   }
}

/**
 * Flush out the transients used in bwater_categorized_blog
 *
 * @since Bwater 1.2
 */
function bwater_category_transient_flusher() {
   // Like, beat it. Dig?
   delete_transient( 'all_the_cool_cats' );
}
add_action( 'edit_category', 'bwater_category_transient_flusher' );
add_action( 'save_post', 'bwater_category_transient_flusher' );

/**
 * Filter in a link to a content ID attribute for the next/previous image links on image attachment pages
 */
function bwater_enhanced_image_navigation( $url ) {
   global $post, $wp_rewrite;

   $id = (int) $post->ID;
   $object = get_post( $id );
   if ( wp_attachment_is_image( $post->ID ) && ( $wp_rewrite->using_permalinks() && ( $object->post_parent > 0 ) && ( $object->post_parent != $id ) ) )
      $url = $url . '#main';

   return $url;
}
add_filter( 'attachment_link', 'bwater_enhanced_image_navigation' );


/**
 * This theme was built with PHP, Semantic HTML, CSS, love, and a Bwater.
 */
